==> bamboo_core-0.9.1.tar.gz: bamboo_core-0.9.1/tests/tests_sticky/http/test_sticky_basic_auth.py <==
import unittest

from bamboo import (
    ASGIApp,
    ASGIHTTPEndpoint,
    WSGIApp,
    WSGIEndpoint,
    WSGIServerForm,
    WSGITestExecutor,
)
from bamboo.request import http
from bamboo.sticky.http import basic_auth
from bamboo.util.convert import encode_base64_string
from bamboo.util.string import rand_string

from ... import get_log_name
from ...asgi_util import ASGIServerForm, ASGITestExecutor


app_asgi = ASGIApp()
app_wsgi = WSGIApp()
PATH_ASGI_SERVER_LOG = get_log_name(__file__, "asgi")
PATH_WSGI_SERVER_LOG = get_log_name(__file__, "wsgi")
RANDOM_CREDENTIALS = [(rand_string(10), rand_string(10)) for _ in range(10)]


def make_basic_credential(user_id: str, pw: str) -> str:
    return encode_base64_string(f"{user_id}:{pw}")


@app_asgi.route()
class TestASGIHTTPEndpoint(ASGIHTTPEndpoint):

    @basic_auth()
    async def do_HEAD(self, user_id: str, pw: str) -> None:
        self.send_only_status()


@app_wsgi.route()
class TestWSGIEndpoint(WSGIEndpoint):

    @basic_auth()
    def do_HEAD(self, user_id: str, pw: str) -> None:
        self.send_only_status()


class TestStickyRestrictsClient(unittest.TestCase):

    @classmethod
    def setUpClass(cls) -> None:
        form_asgi = ASGIServerForm("", 8000, app_asgi, PATH_ASGI_SERVER_LOG)
        form_wsgi = WSGIServerForm("", 8001, app_wsgi, PATH_WSGI_SERVER_LOG)
        cls.executor_asgi = ASGITestExecutor(form_asgi).start_serve()
        cls.executor_wsgi = WSGITestExecutor(form_wsgi).start_serve()
        cls.uri_asgi = "http://localhost:8000"
        cls.uri_wsgi = "http://localhost:8001"

    @classmethod
    def tearDownClass(cls) -> None:
        cls.executor_asgi.close()
        cls.executor_wsgi.close()

    def test_asgi(self):
        for user_id, pw in RANDOM_CREDENTIALS:
            formatted = make_basic_credential(user_id, pw)
            headers = {"Authorization": "Basic " + formatted}
            with http.head(self.uri_asgi, headers=headers) as res:
                self.assertTrue(res.ok)

    def test_wsgi(self):
        for user_id, pw in RANDOM_CREDENTIALS:
            formatted = make_basic_credential(user_id, pw)
            headers = {"Authorization": "Basic " + formatted}
            with http.head(self.uri_wsgi, headers=headers) as res:
                self.assertTrue(res.ok)


if __name__ == "__main__":
    unittest.main()

==> bamboo_core-0.10.0.tar.gz: bamboo_core-0.10.0/tests/tests_sticky/http/test_sticky_basic_auth.py <==
import unittest

from bamboo import (
    ASGIApp,
    ASGIHTTPEndpoint,
    WSGIApp,
    WSGIEndpoint,
    WSGIServerForm,
    WSGITestExecutor,
)
from bamboo.request import http
from bamboo.sticky.http import basic_auth
from bamboo.util.convert import encode_base64_string
from bamboo.util.string import rand_string

from ... import get_log_name
from ...asgi_util import ASGIServerForm, ASGITestExecutor


app_asgi = ASGIApp()
app_wsgi = WSGIApp()
PATH_ASGI_SERVER_LOG = get_log_name(__file__, "asgi")
PATH_WSGI_SERVER_LOG = get_log_name(__file__, "wsgi")
RANDOM_CREDENTIALS = [(rand_string(10), rand_string(10)) for _ in range(10)]


def make_basic_credential(user_id: str, pw: str) -> str:
    return encode_base64_string(f"{user_id}:{pw}")


@app_asgi.route()
class TestASGIHTTPEndpoint(ASGIHTTPEndpoint):

    @basic_auth()
    async def do_HEAD(self, user_id: str, pw: str) -> None:
        self.send_only_status()


@app_wsgi.route()
class TestWSGIEndpoint(WSGIEndpoint):

    @basic_auth()
    def do_HEAD(self, user_id: str, pw: str) -> None:
        self.send_only_status()


class TestStickyVasicAuth(unittest.TestCase):

    @classmethod
    def setUpClass(cls) -> None:
        form_asgi = ASGIServerForm("", 8000, app_asgi, PATH_ASGI_SERVER_LOG)
        form_wsgi = WSGIServerForm("", 8001, app_wsgi, PATH_WSGI_SERVER_LOG)
        cls.executor_asgi = ASGITestExecutor(form_asgi).start_serve()
        cls.executor_wsgi = WSGITestExecutor(form_wsgi).start_serve()
        cls.uri_asgi = "http://localhost:8000"
        cls.uri_wsgi = "http://localhost:8001"

    @classmethod
    def tearDownClass(cls) -> None:
        cls.executor_asgi.close()
        cls.executor_wsgi.close()

    def test_asgi(self):
        for user_id, pw in RANDOM_CREDENTIALS:
            formatted = make_basic_credential(user_id, pw)
            headers = {"Authorization": "Basic " + formatted}
            with http.head(self.uri_asgi, headers=headers) as res:
                self.assertTrue(res.ok)

    def test_wsgi(self):
        for user_id, pw in RANDOM_CREDENTIALS:
            formatted = make_basic_credential(user_id, pw)
            headers = {"Authorization": "Basic " + formatted}
            with http.head(self.uri_wsgi, headers=headers) as res:
                self.assertTrue(res.ok)


if __name__ == "__main__":
    unittest.main()
